package gov.usgs.earthquake.nshmp.netcdf;

import java.nio.file.Path;
import java.util.List;
import java.util.Set;

import gov.usgs.earthquake.nshmp.gmm.Imt;

/**
 * Read in and parse a single hazard NetCDF data file.
 *
 * @author U.S. Geological Survey
 */
public class NetcdfDataFilesHazardCurves extends NetcdfDataFiles<NetcdfHazardCurves> {

  public NetcdfDataFilesHazardCurves(Path netcdfPath) {
    super(netcdfPath, NetcdfDataType.HAZARD_CURVES);
    addAll(readFiles(netcdfPath, dataType()));
  }

  /**
   * Returns the set of IMTs.
   */
  public Set<Imt> imts() {
    return Set.copyOf(netcdf().netcdfData().imts());
  }

  /**
   * Returns the Netcdf object.
   */
  public NetcdfHazardCurves netcdf() {
    return stream()
        .findFirst()
        .orElseThrow(() -> new IllegalArgumentException("Data set not found"));
  }

  @Override
  protected List<NetcdfHazardCurves> readFiles(Path netcdfPath, NetcdfDataType dataType) {
    NetcdfDataType fileDataType = NetcdfDataType.getDataType((netcdfPath));

    if (!fileDataType.equals(dataType)) {
      throw new RuntimeException(
          String.format("Data type %s of file must be of type %s", fileDataType, dataType));
    } ;

    NetcdfHazardCurves data = new NetcdfHazardCurves(netcdfPath);
    return List.of(data);
  }
}
