package gov.usgs.earthquake.nshmp.netcdf.data;

import static com.google.common.base.Preconditions.checkState;

import java.util.Map;

import gov.usgs.earthquake.nshmp.geo.json.FeatureCollection;
import gov.usgs.earthquake.nshmp.gmm.Imt;

/**
 * NetCDF data for hazard curves.
 *
 * @author U.S. Geological Survey
 */
public class NetcdfDataHazardCurves extends NetcdfData {

  private final Map<Imt, double[]> imls;
  private final FeatureCollection map;
  private final FeatureCollection sites;

  public NetcdfDataHazardCurves(
      NetcdfData netcdfData,
      Map<Imt, double[]> imls,
      FeatureCollection map,
      FeatureCollection sites) {
    super(NetcdfData.Builder.copyOf(netcdfData));
    checkState(!imls.isEmpty(), "Must add imls");
    this.imls = imls;
    this.map = map;
    this.sites = sites;
  }

  /**
   * Returns the Imls
   */
  public Map<Imt, double[]> imls() {
    return imls;
  }

  /**
   * Returns the map boundary feature collection.
   */
  public FeatureCollection map() {
    return map;
  }

  /**
   * Returns the number of Imls
   */
  public int nIml() {
    return imls.values().iterator().next().length;
  }

  /**
   * Returns the test sites feature collection.
   */
  public FeatureCollection sites() {
    return sites;
  }

  public static Builder builder() {
    return new Builder();
  }
}
