package gov.usgs.earthquake.nshmp.netcdf.www;

import java.io.IOException;
import java.util.List;

import gov.usgs.earthquake.nshmp.netcdf.data.ScienceBaseMetadata;
import gov.usgs.earthquake.nshmp.www.SwaggerUtils;

import io.micronaut.http.HttpRequest;
import io.swagger.v3.oas.models.OpenAPI;

/**
 * Swagger page updates for hazard services.
 *
 * @author U.S. Geological Survey
 */
public class SwaggerHazardCurves extends Swagger<NetcdfServiceHazardCurves> {

  SwaggerHazardCurves(HttpRequest<?> request, NetcdfServiceHazardCurves service) {
    super(request, service);
  }

  @Override
  String description() {
    StringBuilder builder = new StringBuilder();

    service.netcdfDataFiles()
        .forEach(netcdf -> {
          ScienceBaseMetadata metadata = netcdf.netcdfData().scienceBaseMetadata();
          builder
              .append(metadata.description + "\n")
              .append(parameterSection(netcdf.netcdfData()) + "\n")
              .append(scienceBaseSection(metadata) + "\n");
        });

    return builder.toString();
  }

  @Override
  String descriptionHeader() {
    return "";
  }

  @Override
  String serviceInfo() {
    return "";
  }

  @Override
  String servicePatternSection() {
    var url = NetcdfWsUtils.getRequestUrl(request);
    url = url.endsWith("/swagger") ? url.replace("/swagger", "") : url;

    return new StringBuilder()
        .append(
            "<details>\n" +
                "<summary>Service Call Patterns</summary>\n")
        .append(
            "### Query Pattern\n" +

                "The query based service call is in the form of:\n" +

                "```text\n" +
                url + "/hazard?longitude={number}&latitude={number}\n" +
                url + "/hazard?longitude={number}&latitude={number}&siteClass={string}\n" +
                url + "/hazard" +
                "?longitude={number}&latitude={number}&siteClass={string}&imt={string}\n" +
                "````\n" +

                "Example:\n" +
                "```text\n" +
                url + "/hazard?longitude=-118&latitude=34\n" +
                url + "/hazard?longitude=-118&latitude=34&siteClass=BC\n" +
                url + "/hazard?longitude=-118&latitude=34&siteClass=BC&imt=PGA\n" +
                "```\n")
        .append(
            "### Slash Pattern\n" +

                "The slash based service call is in the form of:\n" +

                "```text\n" +
                url + "/hazard/{longitude}/{latitude}\n" +
                url + "/hazard/{longitude}/{latitude}/{siteClass}\n" +
                url + "/hazard/{longitude}/{latitude}/{siteClass}/{imt}\n" +
                "```\n" +

                "Example:\n" +

                "```text\n" +
                url + "/hazard/-118/34\n" +
                url + "/hazard/-118/34/BC\n" +
                url + "/hazard/-118/34/BC/PGA\n" +
                "```\n")
        .append("</details>")
        .toString();
  }

  @Override
  OpenAPI updateOpenApi() throws IOException {
    OpenAPI openApi = super.updateOpenApi();

    SwaggerUtils.imtSchema(
        openApi.getComponents().getSchemas(),
        List.copyOf(service.netcdfDataFiles().imts()));

    return openApi;
  }
}
