package gov.usgs.earthquake.nshmp.netcdf.www;

import gov.usgs.earthquake.nshmp.gmm.NehrpSiteClass;
import gov.usgs.earthquake.nshmp.netcdf.www.Request.RequestData;
import gov.usgs.earthquake.nshmp.netcdf.www.Request.RequestDataSiteClass;
import gov.usgs.earthquake.nshmp.netcdf.www.meta.DoubleParameter;

import io.micronaut.http.HttpRequest;

/**
 * Web service metadata.
 *
 * @author U.S. Geological Survey
 */
public class Metadata<S, T extends Query> {
  public final String description;
  public final String[] syntax;
  public final S models;
  public final DoubleParameter vs30;

  Metadata(HttpRequest<?> request, NetcdfService<S, T> netcdfService, String description) {
    var url = request.getUri().toString();
    url = url.endsWith("/") ? url.substring(0, url.length() - 1) : url;
    this.description = description;
    syntax = new String[] {
        url + "/{longitude:number}/{latitude:number}",
        url + "?longitude={number}&latitude={number}",
        url + "/{longitude:number}/{latitude:number}/{siteClass:NehrpSiteClass}",
        url + "?longitude={number}&latitude={number}&siteClass={NehrpSiteClass}",
    };

    models = netcdfService.getSourceModels();

    vs30 = new DoubleParameter(
        "Vs30",
        "m/s",
        150,
        1500);
  }

  interface ServiceMetadata {
    RequestData toRequestMetadata(RequestData requestData);
  }

  static class ServiceResponseMetadata implements ServiceMetadata {
    public NehrpSiteClass siteClass;
    public String xLabel;
    public String yLabel;

    ServiceResponseMetadata(
        NehrpSiteClass siteClass,
        String xLabel,
        String yLabel) {
      this.siteClass = siteClass;
      this.xLabel = xLabel;
      this.yLabel = yLabel;
    }

    @Override
    public RequestDataSiteClass toRequestMetadata(RequestData requestData) {
      return new RequestDataSiteClass(requestData.site, siteClass, requestData.format);
    }
  }
}
