package gov.usgs.earthquake.nshmp.netcdf.www;

import static com.google.common.base.CaseFormat.UPPER_CAMEL;
import static com.google.common.base.CaseFormat.UPPER_UNDERSCORE;

import java.util.Optional;
import java.util.logging.Logger;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;

import gov.usgs.earthquake.nshmp.gmm.Imt;
import gov.usgs.earthquake.nshmp.netcdf.NetcdfVersion;
import gov.usgs.earthquake.nshmp.www.ResponseBody;
import gov.usgs.earthquake.nshmp.www.ResponseMetadata;
import gov.usgs.earthquake.nshmp.www.WsUtils.EnumSerializer;
import gov.usgs.earthquake.nshmp.www.WsUtils.NaNSerializer;

import io.micronaut.http.HttpRequest;
import io.micronaut.http.HttpResponse;

public class NetcdfWsUtils {
  static final Gson GSON;

  private static final Logger LOGGER = Logger.getLogger(NetcdfWsUtils.class.getName());

  static {
    GSON = new GsonBuilder()
        .registerTypeAdapter(Imt.class, new EnumSerializer<Imt>())
        .registerTypeAdapter(Double.class, new NaNSerializer())
        .disableHtmlEscaping()
        .serializeNulls()
        .setPrettyPrinting()
        .create();
  }

  public static String getRequestUrl(HttpRequest<?> request) {
    var host = Optional.of(request.getHeaders().get("Host")).orElse("");
    host = host.endsWith("/") ? host.substring(0, host.length() - 1) : host;
    var scheme = request.getHeaders().get("X-Forwarded-Proto");
    var url = host + request.getUri().toString();
    url = scheme != null ? scheme + "://" + url : url;
    return url;
  }

  public static HttpResponse<String> handleError(
      Throwable e,
      String name,
      String url) {
    var msg = e.getMessage() + " (see logs)";
    var svcResponse = ResponseBody.error()
        .metadata(new ResponseMetadata(NetcdfVersion.appVersions()))
        .name(name)
        .request(url)
        .response(msg)
        .url(url)
        .build();
    var response = GSON.toJson(svcResponse);
    LOGGER.severe(name + " -\n" + response);
    e.printStackTrace();
    return HttpResponse.serverError(response);
  }

  public static enum Key {
    LATITUDE,
    LONGITUDE,
    SITE_CLASS,
    IMT;

    @Override
    public String toString() {
      return UPPER_UNDERSCORE.to(UPPER_CAMEL, name());
    }
  }
}
